==> dipdup-6.0.0rc2.tar.gz: dipdup-6.0.0rc2/README.md <==
[![Python](https://img.shields.io/badge/made%20with-python-blue.svg?)](https://www.python.org)
[![GitHub stars](https://img.shields.io/github/stars/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py)
[![Latest stable release](https://img.shields.io/github/v/release/dipdup-net/dipdup-py?label=stable)](https://github.com/dipdup-net/dipdup-py/releases)
[![Latest pre-release)](https://img.shields.io/github/v/release/dipdup-net/dipdup-py?include_prereleases&label=latest)](https://github.com/dipdup-net/dipdup-py/releases)
[![PyPI monthly downloads](https://img.shields.io/pypi/dm/dipdup)](https://pypi.org/project/dipdup/)
<br>
[![GitHub tests](https://img.shields.io/github/workflow/status/dipdup-net/dipdup-py/Test)](https://github.com/dipdup-net/dipdup-py/actions)
[![GitHub issues](https://img.shields.io/github/issues/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py/pulls)
[![License: MIT](https://img.shields.io/github/license/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py/blob/master/LICENSE)

```text
        ____   _         ____              
       / __ \ (_)____   / __ \ __  __ ____ 
      / / / // // __ \ / / / // / / // __ \
     / /_/ // // /_/ // /_/ // /_/ // /_/ /
    /_____//_// .___//_____/ \__,_// .___/ 
             /_/                  /_/      
```

DipDup is a Python framework for building indexers of [Tezos](https://tezos.com/) smart-contracts. It helps developers focus on the business logic instead of writing data storing and serving boilerplate. DipDup-based indexers are selective, which means only required data is requested. This approach allows to achieve faster indexing times and decreased load on APIs DipDup uses.

* **Ready to build your first indexer?** Head to [Quickstart](https://dipdup.net/docs/quickstart).

* **Looking for examples?** Check out [Demo Projects](https://github.com/dipdup-net/dipdup-py/tree/master/src).

* **Want to contribute?** See [Contribution Guide](https://github.com/dipdup-net/dipdup-py/tree/master/CONTRIBUTING.md).

* **Have a question?** Contact us on [Discord](https://discord.com/invite/RcPGSdcVSx), [Telegram](https://t.me/baking_bad_chat), or [Slack](https://tezos-dev.slack.com/archives/CV5NX7F2L)!

This project is maintained by the [Baking Bad](https://baking-bad.org/) team.
Development is supported by [Tezos Foundation](https://tezos.foundation/).

==> dipdup-6.1.2.tar.gz: dipdup-6.1.2/README.md <==
[![Python](https://img.shields.io/badge/made%20with-python-blue.svg?)](https://www.python.org)
[![GitHub stars](https://img.shields.io/github/stars/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py)
[![Latest stable release](https://img.shields.io/github/v/release/dipdup-net/dipdup-py?label=stable)](https://github.com/dipdup-net/dipdup-py/releases)
[![Latest pre-release)](https://img.shields.io/github/v/release/dipdup-net/dipdup-py?include_prereleases&label=latest)](https://github.com/dipdup-net/dipdup-py/releases)
[![PyPI monthly downloads](https://img.shields.io/pypi/dm/dipdup)](https://pypi.org/project/dipdup/)
<br>
[![GitHub tests](https://img.shields.io/github/workflow/status/dipdup-net/dipdup-py/Test)](https://github.com/dipdup-net/dipdup-py/actions)
[![GitHub issues](https://img.shields.io/github/issues/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py/pulls)
[![License: MIT](https://img.shields.io/github/license/dipdup-net/dipdup-py)](https://github.com/dipdup-net/dipdup-py/blob/master/LICENSE)

```text
        ____   _         ____              
       / __ \ (_)____   / __ \ __  __ ____ 
      / / / // // __ \ / / / // / / // __ \
     / /_/ // // /_/ // /_/ // /_/ // /_/ /
    /_____//_// .___//_____/ \__,_// .___/ 
             /_/                  /_/      
```

DipDup is a Python framework for building indexers of [Tezos](https://tezos.com/) smart contracts. It helps developers focus on the business logic instead of writing data storing and serving boilerplate. DipDup-based indexers are selective, which means only required data is requested. This approach allows to achieve faster indexing times and decreased load on APIs DipDup uses.

* **Ready to build your first indexer?** Head to [Quickstart](https://dipdup.net/docs/quickstart).

* **Looking for examples?** Check out [Demo Projects](https://github.com/dipdup-net/dipdup-py/tree/master/src).

* **Want to contribute?** See [Contribution Guide](https://github.com/dipdup-net/dipdup-py/tree/master/CONTRIBUTING.md).

* **Have a question?** Contact us on [Discord](https://discord.com/invite/RcPGSdcVSx), [Telegram](https://t.me/baking_bad_chat), or [Slack](https://tezos-dev.slack.com/archives/CV5NX7F2L)!

This project is maintained by the [Baking Bad](https://baking-bad.org/) team.
<br>
Development is supported by [Tezos Foundation](https://tezos.foundation/).
